/*
 * File:   KNA9pentagonC.c
 * Version : 2.0
 * Author: shima(JR1KNA)
 * Device: PIC12F1501
 * Created on 2021/08/07, 15:00
 */

#include <xc.h>
//#include <stdlib.h>
#ifndef _XTAL_FREQ
 // Unless already defined assume 4MHz system frequency
 // This definition is required to calibrate __delay_us() and __delay_ms()
 #define _XTAL_FREQ 4000000
#endif

// CONFIG1
#pragma config FOSC = INTOSC    // Oscillator Selection Bits (INTOSC oscillator: I/O function on CLKIN pin)
#pragma config WDTE = OFF       // Watchdog Timer Enable (WDT disabled)
#pragma config PWRTE = ON       // Power-up Timer Enable (PWRT enabled)
#pragma config MCLRE = OFF      // MCLR Pin Function Select (MCLR/VPP pin function is digital input)
#pragma config CP = OFF         // Flash Program Memory Code Protection (Program memory code protection is disabled)
#pragma config BOREN = OFF      // Brown-out Reset Enable (Brown-out Reset disabled)
#pragma config CLKOUTEN = OFF   // Clock Out Enable (CLKOUT function is disabled. I/O or oscillator function on the CLKOUT pin)

// CONFIG2
#pragma config WRT = OFF        // Flash Memory Self-Write Protection (Write protection off)
#pragma config STVREN = OFF     // Stack Overflow/Underflow Reset Enable (Stack Overflow or Underflow will not cause a Reset)
#pragma config BORV = LO        // Brown-out Reset Voltage Selection (Brown-out Reset Voltage (Vbor), low trip point selected.)
#pragma config LPBOR = OFF      // Low-Power Brown Out Reset (Low-Power BOR is disabled)
#pragma config LVP = OFF        // Low-Voltage Programming Enable (High-voltage on MCLR/VPP must be used for programming)

void init(void)
{
    OPTION_REG = 0b11011111;    // TMR0CS:0 = Internal instruction cycle clock (FOSC/4)
    OSCCON = 0b01101010;        //01101 =4 MHz, 01x = Internal oscillator block
    T1CON = 0b00010100;         //bit 5-4:11 = 1:8 Prescale Value, bit 2:1 = Do not synchronize external clock, bit 0:1 = Enables Timer1
    INTCON = 0b10001000;        //bit 7 GIE: Global Interrupt Enable, bit 6 PEIE: Peripheral Interrupt Enable, bit 3 IOCIE: Interrupt-on-Change Enable bit
    IOCAN = 0b00001000;         //IOCAN<5:0>: Interrupt-on-Change PORTA Negative Edge Enable bits
    IOCAP = 0b00001000;
    PIE1 = 0b00000001;          //bit 0 TMR1IE: TMR1 Overflow Interrupt Enable bit
    ANSELA = 0b00000000;        //PORTA ANALOG SELECT REGISTER
    TRISA = 0b00001000;         // 1 = PORTA pin configured as an input (tri-stated), 0 = PORTA pin configured as an output
    PORTA = 0b00000000;         //RA<5:0>: PORTA I/O Value bits
}
unsigned char timr;
void main(void)
{
	init();
    
    while(!RA3){}
    __delay_ms(500);
    
    TRISA = 0b00111111;
    timr = 2;
    while(1){
        if(timr==0){
            timr = TMR0&0b00000111;
            //timr = timr*20 + 40 + 20;
            timr = timr*5 + 26 + 31;
            TRISA = 0b00111111;
        }
        if(RA3){--timr;}
        //if(timr<40){TRISA = 0b00001000;}
        if(timr<26){TRISA = 0b00001000;}
        //if(timr<5){
        if(timr<4){    
                __delay_ms(200);
                RA0 = RA1 = 1;
                __delay_ms(200);
                RA0 = RA1 = RA2 = RA4 = RA5 = 0;
                __delay_ms(125);
                RA0 = RA1 = RA2 = RA4 = RA5 = 1;
                __delay_ms(125);
                RA0 = RA1 = RA2 = RA4 = RA5 = 0;
                __delay_ms(125);
                RA0 = RA1 = RA2 = RA4 = RA5 = 1;
                __delay_ms(125);
                RA0 = RA1 = RA2 = RA4 = RA5 = 0;
        }
        RA0 = 0;
        __delay_ms(200);
        RA1 = 1;
        RA5 = 0;
        __delay_ms(200);
        RA0 = 1;
        RA4 = 0;
        __delay_ms(200);
        RA5 = 1;
        RA2 = 0;
        __delay_ms(200);
        RA4 = 1;
        RA1 = 0;
        __delay_ms(200);
        RA2 = 1;
    }
}
void interrupt isr(void)
{
    if(!RA3){
        //timr = 5;
        timr = 4;
    }

    IOCAF3 = 0; 
}